@@ -110,7 +110,7 @@ static void gb_assistant_button_clicked(GtkButton * button,
 	gst_element_set_state(recorder, GST_STATE_PLAYING);
 	tag_list = gst_tag_list_new (GST_TAG_ARTIST, gtk_entry_get_text(GTK_ENTRY(musician_entry)), NULL);
 	gst_stream_set_tags (GST_STREAM (recorder), tag_list);
-	tag_list = gst_tag_list_new (GST_TAG_ALBUM, gtk_entry_get_text(GTK_ENTRY(song_entry)), NULL);
+	tag_list = gst_tag_list_new (GST_TAG_ALBUM, gtk_entry_get_text(GTK_ENTRY(album_entry)), NULL);
 	gst_stream_set_tags (GST_STREAM (recorder), tag_list);
 	tag_list = gst_tag_list_new (GST_TAG_TITLE, gtk_entry_get_text(GTK_ENTRY(song_entry)), NULL);
 	gst_stream_set_tags (GST_STREAM (recorder), tag_list);
@@ -186,6 +186,7 @@ static void gb_assistant_close(GtkAssistant * assistant, gpointer data)
 	fprintf(fp, "</gingerblue>\n");
 	fclose(fp);
 	g_date_time_unref (datestamp);
+	gst_element_send_event(data, gst_event_new_eos());
 }
 
 static void gb_assistant_apply(GtkAssistant * assistant, gpointer data)
@@ -405,9 +406,9 @@ int main(int argc, char **argv)
 	g_signal_connect(G_OBJECT(introduction), "cancel",
 			 G_CALLBACK(gb_assistant_cancel), main_loops);
 	g_signal_connect(G_OBJECT(introduction), "close",
-			 G_CALLBACK(gb_assistant_close), main_loops);
+			 G_CALLBACK(gb_assistant_close), pipeline);
 	g_signal_connect(G_OBJECT(introduction), "apply",
-			 G_CALLBACK(gb_assistant_apply), pipeline);
+			 G_CALLBACK(gb_assistant_close), pipeline);
 /* musicianpage = gtk_entry_new (); */
 	/* real_time = g_get_real_time(); */
 	/* gtk_assistant_insert_page (introduction, */
