@@ -3,7 +3,7 @@
    Copyright (C) 2018-2021 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 0.7.0 (2021-07-14)
+   Version: 1.1.0 (2021-07-27)
    Website: http://www.gingerblue.org/
    
 */
@@ -22,3 +22,10 @@ void stopRecording();
 void startRecording();
 int sigintHandler(int unused);
 int gb_record_cb (gchar *path);
+
+int gingerblue_record_begin();
+int gingerblue_record_end();
+
+typedef struct _GingerblueRecord {
+  gboolean recording_found;
+} GingerblueRecord;
